#!/usr/bin/env python3
# -*- coding: utf-8 -*-



import mirrors as m
import tbox
import tbox.gmsh as gmsh
import fwk.wutils as wu
from fwk.coloring import ccolors

def main():
    print(ccolors.ANSI_RED + "mirrors01_ansys.msh contains inverted Tri3 elements. Test will fail!" + ccolors.ANSI_RESET)
    loader = gmsh.MeshLoader("mirrors01_ansys.msh",__file__)
    msh = loader.execute()
    #print msh

    pbl = m.Problem(msh,"thermomechanical",22)
    #pbl = m.Problem(msh,"thermal",22)
    m.ANSYSSolution(pbl,'T','T_ansys',wu.pth('mirrors01_T.ansys',__file__))
    #m.ANSYSSolution(pbl,'u','u_ansys_mech','mirrors07_u.ansys')
    #m.ANSYSSolution(pbl,'x','x_ansys_mech','mirrors07_x.ansys')
    #m.ANSYSSolution(pbl,'y','y_ansys_mech','mirrors07_y.ansys')
    #m.ANSYSSolution(pbl,'z','z_ansys_mech','mirrors07_z.ansys')
    m.ANSYSSolution(pbl,'u','u_ansys_thermomech',wu.pth('mirrors01_u_thermo.ansys',__file__))
    m.ANSYSSolution(pbl,'x','x_ansys_thermomech',wu.pth('mirrors01_x_thermo.ansys',__file__))
    m.ANSYSSolution(pbl,'y','y_ansys_thermomech',wu.pth('mirrors01_y_thermo.ansys',__file__))
    m.ANSYSSolution(pbl,'z','z_ansys_thermomech',wu.pth('mirrors01_z_thermo.ansys',__file__))
    #print pbl

    m.Medium(pbl, "Volume", "TZM",330000,0.36,0.114,0.5E-05)
    #print pbl
    clamped = tbox.Vector3d(1,1,1)
    values_clamped = tbox.Vector3d(0,0,0)
    forces = tbox.Vector3d(-0.2,0,0)
    
    m.uDirichlet(pbl, "M1_S1", "Clamped",clamped,values_clamped)
    m.uDirichlet(pbl, "M1_S2", "Clamped",clamped,values_clamped)
    m.uDirichlet(pbl, "M1_S3", "Clamped",clamped,values_clamped)
    m.uDirichlet(pbl, "M1_B1", "Clamped",clamped,values_clamped)
    m.uDirichlet(pbl, "M1_B2", "Clamped",clamped,values_clamped)
    m.uDirichlet(pbl, "M1_B3", "Clamped",clamped,values_clamped)
    m.TDirichlet(pbl, "M1_S1", "Clamped",70.)
    m.TDirichlet(pbl, "M1_S2", "Clamped",70.)
    m.TDirichlet(pbl, "M1_S3", "Clamped",70.)
    m.TDirichlet(pbl, "M1_B1", "Clamped",70.)
    m.TDirichlet(pbl, "M1_B2", "Clamped",70.)
    m.TDirichlet(pbl, "M1_B3", "Clamped",70.)
    m.TNeumann(pbl, "HF", "HF",1.E-002)
    m.MSurface(pbl, "HF", "M1",tbox.Vector3d(-85.853,-244.29,-12.597),tbox.Vector3d(-0.93316,-0.20444,-0.29566),tbox.Vector3d(9.5044E-04,0.8511,-0.57078))
    #m.uNeumann(pbl, "HF", "HF",clamped,forces)
    m.TSource(pbl, "Volume", "ihg",1.7E-004)
    #m.TDirichlet(pbl, "hf", "Clamped",80.)
    #print pbl

    from fwk.wutils import parseargs
    args=parseargs()

    solver = m.Solver(pbl,args.k)
    solver.start()

    for i in range(0,len(pbl.ANSYSSol)):
       print(pbl.ANSYSSol[i].diff_abs)
       print(pbl.ANSYSSol[i].diff_rel)

    if not args.nogui:
        from mirrors.viewer import GUI
        GUI().open( loader.filename )

if __name__ == "__main__":
    main()
